searchData={"items":[{"type":"module","title":"Cache.Metrics","doc":"Add the following metrics for elixir_cache:\n\nMetrics included:\n  - `elixir_cache.cache.get.count`\n  - `elixir_cache.cache.get.miss.count`\n  - `elixir_cache.cache.get.error.count`\n  - `elixir_cache.cache.put.count`\n  - `elixir_cache.cache.delete.count`\n  - `elixir_cache.cache.get.duration.millisecond`","ref":"Cache.Metrics.html"},{"type":"function","title":"Cache.Metrics.metrics/0","doc":"","ref":"Cache.Metrics.html#metrics/0"},{"type":"behaviour","title":"Cache","doc":"# ElixirCache\n[![Hex version badge](https://img.shields.io/hexpm/v/elixir_cache.svg)](https://hex.pm/packages/elixir_cache)\n[![Test](https://github.com/MikaAK/elixir_cache/actions/workflows/test.yml/badge.svg)](https://github.com/MikaAK/elixir_cache/actions/workflows/test.yml)\n[![Credo](https://github.com/MikaAK/elixir_cache/actions/workflows/credo.yml/badge.svg)](https://github.com/MikaAK/elixir_cache/actions/workflows/credo.yml)\n[![Dialyzer](https://github.com/MikaAK/elixir_cache/actions/workflows/dialyzer.yml/badge.svg)](https://github.com/MikaAK/elixir_cache/actions/workflows/dialyzer.yml)\n[![Coverage](https://github.com/MikaAK/elixir_cache/actions/workflows/coverage.yml/badge.svg)](https://github.com/MikaAK/elixir_cache/actions/workflows/coverage.yml)\n\nThe goal of this project is to unify Cache APIs and make Strategies easy to implement and sharable\nacross all storage types/adapters\n\nThe second goal is to make sure testing of all cache related funciions is easy, meaning caches should be isolated\nper test and not leak their state to outside tests","ref":"Cache.html"},{"type":"behaviour","title":"Installation - Cache","doc":"The package can be installed by adding `elixir_cache` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elixir_cache, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"Cache.html#module-installation"},{"type":"behaviour","title":"Usage - Cache","doc":"```elixir\ndefmodule MyModule do\n  use Cache,\n    adapter: Cache.Redis,\n    name: :my_name,\n    sandbox?: Mix.env() === :test,\n    opts: [...opts]\nend\n```\n\nIn our `application.ex`\n```elixir\nchildren = [\n  {Cache, [MyModule]}\n]\n```\n\nNow we can use `MyModule` to call various Cache apis\n\n```elixir\nMyModule.get(\"key\") #> {:ok, nil}\nMyModule.put(\"key\", \"value\") #> :ok\nMyModule.get(\"key\") #> {:ok, \"value\"}\n```","ref":"Cache.html#module-usage"},{"type":"behaviour","title":"Adapters - Cache","doc":"- `Cache.Agent` - Simple agent based caching\n- `Cache.DETS`  - Disk persisted caching with [dets](https://www.erlang.org/doc/man/dets.html)\n- `Cache.ETS`   - Super quick in-memory cache with [`ets`](https://www.erlang.org/doc/man/ets.html)\n- `Cache.Redis` - Caching adapter using [Redix](https://github.com/whatyouhide/redix) & [Poolboy](https://github.com/devinus/poolboy), supports Redis JSON an Redis Hashes\n- `Cache.ConCache` - Wrapper around [ConCache](https://github.com/sasa1977/con_cache) library\n\n#### Adapter Specific Functions\nSome adapters have specific functions such as redis which has hash functions and pipeline functions to make calls easier.\n\nThese adapter when used will add extra commands to your cache module.","ref":"Cache.html#module-adapters"},{"type":"behaviour","title":"Sandboxing - Cache","doc":"Our cache config accepts a `sandbox?: boolean`. In sandbox mode, the `Cache.Sandbox` adapter will be used, which is just a simple Agent cache unique to the root process. The `Cache.SandboxRegistry` is responsible for registering test processes to a\nunique instance of the Sandbox adapter cache. This makes it safe in test mode to run all your tests asynchronously!\n\nFor test isolation via the `Cache.SandboxRegistry` to work, you must start the registry in your setup, or your test_helper.exs:\n\n```elixir\n# test/test_helper.exs\n\n+ Cache.SandboxRegistry.start_link()\nExUnit.start()\n\n```\n\nThen inside our `setup` for a test we can do:\n\n```elixir\nCache.SandboxRegistry.start([MyCache, CacheItem])\n```","ref":"Cache.html#module-sandboxing"},{"type":"behaviour","title":"Creating Adapters - Cache","doc":"Adapters are very easy to create in this model and are basically just a module that implement the `@behaviour Cache`\n\nThis behaviour adds the following callbacks\n\n```\nput(cache_name, key, ttl, value, opts \\\\ [])\nget(cache_name, key, opts \\\\ [])\ndelete(cache_name, key, opts \\\\ [])\nopts_definition() # NimbleOptions definition map\nchild_spec({cache_name, cache_opts})\n```\n\n`Cache.ETS` is probably the easiest adapter to follow as a guide as it's a simple `Task`","ref":"Cache.html#module-creating-adapters"},{"type":"behaviour","title":"Runtime Configuration - Cache","doc":"Adapter configuration can also be specified at runtime. These options are first passed to the adapter\nchild_spec when starting the adapter and then passed to all runtime function calls.\n\nFor example:\n\n```elixir\n  # Configure with Module Function\n  defmodule Cache.Example do\n    use Cache,\n      adapter: Cache.Redis,\n      name: :test_cache_redis,\n      opts: {Cache.Example, :opts, []}\n\n    def opts, do: [host: \"localhost\", port: 6379]\n  end\n\n  # Configure with callback function\n  defmodule Cache.Example do\n    use Cache,\n      adapter: Cache.Redis,\n      name: :test_cache_redis,\n      opts: &Cache.Example.opts/0\n\n    def opts, do: [host: \"localhost\", port: 6379]\n  end\n\n  # Fetch from application config\n  # config :elixir_cache, Cache.Example, []\n  defmodule Cache.Example do\n    use Cache,\n      adapter: Cache.Redis,\n      name: :test_cache_redis,\n      opts: :elixir_cache\n  end\n\n  # Fetch from application config\n  # config :elixir_cache, :cache_opts, []\n  defmodule Cache.Example do\n    use Cache,\n      adapter: Cache.Redis,\n      name: :test_cache_redis,\n      opts: {:elixir_cache, :cache_opts}\n  end\n```\n\nRuntime options can be configured in one of the following formats:\n\n* `{module, function, args}` - Module, function, args\n* `{application_name, key}` - Application name. This is called as `Application.fetch_env!(application_name, key)`.\n* `application_name` - Application name as an atom. This is called as `Application.fetch_env!(application_name, cache_module})`.\n* `function` - Zero arity callback function. For eg. `&YourModule.options/0`\n* `[key: value_type]` - Keyword list of options.","ref":"Cache.html#module-runtime-configuration"},{"type":"function","title":"Cache.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Cache.html#child_spec/1"},{"type":"callback","title":"Cache.child_spec/1","doc":"","ref":"Cache.html#c:child_spec/1"},{"type":"callback","title":"Cache.delete/2","doc":"","ref":"Cache.html#c:delete/2"},{"type":"callback","title":"Cache.delete/3","doc":"","ref":"Cache.html#c:delete/3"},{"type":"callback","title":"Cache.get/2","doc":"","ref":"Cache.html#c:get/2"},{"type":"callback","title":"Cache.get/3","doc":"","ref":"Cache.html#c:get/3"},{"type":"function","title":"Cache.get_or_create/3","doc":"","ref":"Cache.html#get_or_create/3"},{"type":"function","title":"Cache.init/1","doc":"","ref":"Cache.html#init/1"},{"type":"callback","title":"Cache.opts_definition/0","doc":"","ref":"Cache.html#c:opts_definition/0"},{"type":"callback","title":"Cache.put/4","doc":"","ref":"Cache.html#c:put/4"},{"type":"callback","title":"Cache.put/5","doc":"","ref":"Cache.html#c:put/5"},{"type":"callback","title":"Cache.start_link/1","doc":"","ref":"Cache.html#c:start_link/1"},{"type":"function","title":"Cache.start_link/2","doc":"","ref":"Cache.html#start_link/2"},{"type":"module","title":"Cache.Agent","doc":"This module is the Agent adapter. Very lightweight use only","ref":"Cache.Agent.html"},{"type":"function","title":"Cache.Agent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Cache.Agent.html#child_spec/1"},{"type":"module","title":"Cache.ConCache","doc":"ETS Based cache https://github.com/sasa1977/con_cache\n\nTakes the following options:\n\n * `:acquire_lock_timeout` (`t:pos_integer/0`) - The default value is `5000`.\n\n* `:touch_on_read` (`t:boolean/0`) - The default value is `false`.\n\n* `:global_ttl` - The default value is `1800000`.\n\n* `:ttl_check_interval` - The default value is `60000`.\n\n* `:dirty?` (`t:boolean/0`) - Use dirty_put instead of locking to put, enabled by default The default value is `true`.\n\n* `:ets_options` - https://www.erlang.org/doc/man/ets.html#new-2","ref":"Cache.ConCache.html"},{"type":"function","title":"Cache.ConCache.dirty_get_or_store/3","doc":"","ref":"Cache.ConCache.html#dirty_get_or_store/3"},{"type":"type","title":"Cache.ConCache.ets_option/0","doc":"","ref":"Cache.ConCache.html#t:ets_option/0"},{"type":"function","title":"Cache.ConCache.get_or_store/4","doc":"Implements a version of get_or_store that locks locally\nso only one process runs `store_fun` at a time.\n\nAny other processes that miss cache will wait for the first\ncaller to finish `store_fun` then will read the result from cache.","ref":"Cache.ConCache.html#get_or_store/4"},{"type":"type","title":"Cache.ConCache.opts/0","doc":"","ref":"Cache.ConCache.html#t:opts/0"},{"type":"module","title":"Cache.DETS","doc":"DETS adapter so that we can use dets as a cache","ref":"Cache.DETS.html"},{"type":"module","title":"Options - Cache.DETS","doc":"* `:ram_file` (`t:boolean/0`) - Enable RAM File The default value is `false`.\n\n* `:type` - Data type of DETS cache The default value is `:set`.\n\n* `:file_path` (`t:String.t/0`) - File path to save DETS file at The default value is `\"./\"`.","ref":"Cache.DETS.html#module-options"},{"type":"function","title":"Cache.DETS.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\n`arg` is passed as the argument to `Task.start_link/1` in the `:start` field\nof the spec.\n\nFor more information, see the `Supervisor` module,\nthe `Supervisor.child_spec/2` function and the `t:Supervisor.child_spec/0` type.","ref":"Cache.DETS.html#child_spec/1"},{"type":"module","title":"Cache.ETS","doc":"ETS adapter so that we can use ets as a cache","ref":"Cache.ETS.html"},{"type":"module","title":"Options - Cache.ETS","doc":"* `:write_concurrency` (`t:boolean/0`) - Enable write concurrency\n\n* `:read_concurrency` (`t:boolean/0`) - Enable read concurrency\n\n* `:decentralized_counters` (`t:boolean/0`) - Use decentralized counters\n\n* `:type` - Data type of ETS cache The default value is `:set`.\n\n* `:compressed` (`t:boolean/0`) - Enable ets compression","ref":"Cache.ETS.html#module-options"},{"type":"function","title":"Cache.ETS.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\n`arg` is passed as the argument to `Task.start_link/1` in the `:start` field\nof the spec.\n\nFor more information, see the `Supervisor` module,\nthe `Supervisor.child_spec/2` function and the `t:Supervisor.child_spec/0` type.","ref":"Cache.ETS.html#child_spec/1"},{"type":"module","title":"Cache.Redis","doc":"This module interacts with redis using a pool of connections","ref":"Cache.Redis.html"},{"type":"module","title":"Options - Cache.Redis","doc":"* `:uri` (`t:String.t/0`) - Required. The connection uri to redis\n\n* `:size` (`t:pos_integer/0`) - The amount of workers in the pool\n\n* `:max_overflow` (`t:pos_integer/0`) - The amount of max overflow the pool can handle\n\n* `:strategy` - The type of queue to use for poolboy","ref":"Cache.Redis.html#module-options"},{"type":"function","title":"Cache.Redis.command/3","doc":"","ref":"Cache.Redis.html#command/3"},{"type":"function","title":"Cache.Redis.command!/3","doc":"","ref":"Cache.Redis.html#command!/3"},{"type":"function","title":"Cache.Redis.hash_delete/4","doc":"","ref":"Cache.Redis.html#hash_delete/4"},{"type":"function","title":"Cache.Redis.hash_get/4","doc":"","ref":"Cache.Redis.html#hash_get/4"},{"type":"function","title":"Cache.Redis.hash_get_all/3","doc":"","ref":"Cache.Redis.html#hash_get_all/3"},{"type":"function","title":"Cache.Redis.hash_get_many/3","doc":"","ref":"Cache.Redis.html#hash_get_many/3"},{"type":"function","title":"Cache.Redis.hash_scan/4","doc":"","ref":"Cache.Redis.html#hash_scan/4"},{"type":"function","title":"Cache.Redis.hash_set/6","doc":"","ref":"Cache.Redis.html#hash_set/6"},{"type":"function","title":"Cache.Redis.hash_set_many/4","doc":"","ref":"Cache.Redis.html#hash_set_many/4"},{"type":"function","title":"Cache.Redis.hash_values/3","doc":"","ref":"Cache.Redis.html#hash_values/3"},{"type":"function","title":"Cache.Redis.json_array_append/5","doc":"","ref":"Cache.Redis.html#json_array_append/5"},{"type":"function","title":"Cache.Redis.json_clear/4","doc":"","ref":"Cache.Redis.html#json_clear/4"},{"type":"function","title":"Cache.Redis.json_delete/4","doc":"","ref":"Cache.Redis.html#json_delete/4"},{"type":"function","title":"Cache.Redis.json_get/4","doc":"","ref":"Cache.Redis.html#json_get/4"},{"type":"function","title":"Cache.Redis.json_incr/5","doc":"","ref":"Cache.Redis.html#json_incr/5"},{"type":"function","title":"Cache.Redis.json_set/5","doc":"","ref":"Cache.Redis.html#json_set/5"},{"type":"function","title":"Cache.Redis.ms_to_nearest_sec/1","doc":"","ref":"Cache.Redis.html#ms_to_nearest_sec/1"},{"type":"function","title":"Cache.Redis.pipeline/3","doc":"","ref":"Cache.Redis.html#pipeline/3"},{"type":"function","title":"Cache.Redis.pipeline!/3","doc":"","ref":"Cache.Redis.html#pipeline!/3"},{"type":"function","title":"Cache.Redis.pool_config/2","doc":"","ref":"Cache.Redis.html#pool_config/2"},{"type":"function","title":"Cache.Redis.scan/3","doc":"","ref":"Cache.Redis.html#scan/3"},{"type":"module","title":"Cache.Sandbox","doc":"This module is the adapter used by the SandboxRegistry to mock out all the other adapters\ntherefore it must implement all features shared across all adapters. It uses a basic `Agent`\nand shouldn't be used in production. It's good for dev & test to avoid needing dependencies","ref":"Cache.Sandbox.html"},{"type":"function","title":"Cache.Sandbox.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Cache.Sandbox.html#child_spec/1"},{"type":"function","title":"Cache.Sandbox.command/3","doc":"","ref":"Cache.Sandbox.html#command/3"},{"type":"function","title":"Cache.Sandbox.command!/3","doc":"","ref":"Cache.Sandbox.html#command!/3"},{"type":"function","title":"Cache.Sandbox.hash_delete/4","doc":"","ref":"Cache.Sandbox.html#hash_delete/4"},{"type":"function","title":"Cache.Sandbox.hash_get/4","doc":"","ref":"Cache.Sandbox.html#hash_get/4"},{"type":"function","title":"Cache.Sandbox.hash_get_all/3","doc":"","ref":"Cache.Sandbox.html#hash_get_all/3"},{"type":"function","title":"Cache.Sandbox.hash_get_many/3","doc":"","ref":"Cache.Sandbox.html#hash_get_many/3"},{"type":"function","title":"Cache.Sandbox.hash_scan/4","doc":"","ref":"Cache.Sandbox.html#hash_scan/4"},{"type":"function","title":"Cache.Sandbox.hash_set/6","doc":"","ref":"Cache.Sandbox.html#hash_set/6"},{"type":"function","title":"Cache.Sandbox.hash_set_many/4","doc":"","ref":"Cache.Sandbox.html#hash_set_many/4"},{"type":"function","title":"Cache.Sandbox.hash_values/3","doc":"","ref":"Cache.Sandbox.html#hash_values/3"},{"type":"function","title":"Cache.Sandbox.json_array_append/5","doc":"","ref":"Cache.Sandbox.html#json_array_append/5"},{"type":"function","title":"Cache.Sandbox.json_clear/4","doc":"","ref":"Cache.Sandbox.html#json_clear/4"},{"type":"function","title":"Cache.Sandbox.json_delete/4","doc":"","ref":"Cache.Sandbox.html#json_delete/4"},{"type":"function","title":"Cache.Sandbox.json_get/4","doc":"","ref":"Cache.Sandbox.html#json_get/4"},{"type":"function","title":"Cache.Sandbox.json_incr/5","doc":"","ref":"Cache.Sandbox.html#json_incr/5"},{"type":"function","title":"Cache.Sandbox.json_set/5","doc":"","ref":"Cache.Sandbox.html#json_set/5"},{"type":"function","title":"Cache.Sandbox.pipeline/3","doc":"","ref":"Cache.Sandbox.html#pipeline/3"},{"type":"function","title":"Cache.Sandbox.pipeline!/3","doc":"","ref":"Cache.Sandbox.html#pipeline!/3"},{"type":"function","title":"Cache.Sandbox.scan/3","doc":"","ref":"Cache.Sandbox.html#scan/3"},{"type":"module","title":"Cache.SandboxRegistry","doc":"This module is used to start the sandbox registry and register caches in test mode\n\nMore details soon...","ref":"Cache.SandboxRegistry.html"},{"type":"function","title":"Cache.SandboxRegistry.find!/2","doc":"","ref":"Cache.SandboxRegistry.html#find!/2"},{"type":"function","title":"Cache.SandboxRegistry.register_caches/2","doc":"","ref":"Cache.SandboxRegistry.html#register_caches/2"},{"type":"function","title":"Cache.SandboxRegistry.start/1","doc":"","ref":"Cache.SandboxRegistry.html#start/1"},{"type":"function","title":"Cache.SandboxRegistry.start_link/0","doc":"","ref":"Cache.SandboxRegistry.html#start_link/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}